//  SuperTuxKart - a fun racing game with go-kart
//  Copyright (C) 2006 SuperTuxKart-Team
//
//  This program is free software; you can redistribute it and/or
//  modify it under the terms of the GNU General Public License
//  as published by the Free Software Foundation; either version 3
//  of the License, or (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#ifndef HEADER_RACE_OPTIONS_H
#define HEADER_RACE_OPTIONS_H

#include "base_gui.hpp"

class RaceOptions: public BaseGUI
{
private:
    int m_difficulty;
    int m_num_karts;
    int m_min_karts;         // minimum number of karts, depending on mode etc.
    int m_num_laps;
    const char *getDifficultyString(int) const;
    void setAllValues();
public:
    RaceOptions();
    ~RaceOptions();

    void select();
    void update(float dt);
    virtual void handle(GameAction, int);
};

#endif
